# Von Maschinen fürs Leben lernen

von Stefan Majewsky, Chaos Computer Club Dresden <mailto:xyrill@c3d2.de>

Der Chaos Computer Club (CCC) ist eine Vereinigung, deren Mitglieder sich hauptsächlich durch technische Expertise auszeichnen. Insofern nimmt die Mehrheit der Gesellschaft überlicherweise an, dass wir alle Probleme technisch lösen wollen: Sicherheit im Netz durch mehr Kryptografie, lebenswertere Innenstädte durch intelligentere Ampelschaltungen, und Virusinfektionen durch eine Contact-Tracing-App. Gerade der CCC zeichnet sich jedoch seit Beginn dadurch aus, dass wir technische und soziale Fragen immer zusammen denken.

Für uns ist es zum Beispiel schon lange offensichtlich, dass man die Frage nach zeitgemäßer Bildung im digitalen Zeitalter nicht allein dadurch beantworten kann, dass die Politik über den Schulen des Landes einen warmen Regen aus Tablets und Notebooks ergehen lässt. Digitale Lerninhalte können sicherlich den Lehralltag bereichern. Aber die entscheidendere Frage ist, inwieweit die Digitalisierung die Grundsätze unseres Bildungssystems in Zweifel zieht. Die fortschreitende Automatisierung macht vielleicht nicht so viele Arbeitsplätze obsolet wie manchmal angenommen, aber an jedem einzelnen Arbeitsplatz werden Routinetätigkeiten zunehmend von Computern übernommen, sodass vom Mitarbeiter verstärkt kreative und analytische Fertigkeiten verlangt werden.

Diesen Wandel muss auch die Bildung begleiten. Anstatt zum Beispiel einen bestimmten Satz von Fakten über ein im Lehrplan vorgegebenes Thema auswendig zu lernen, sollte das Ziel sein, den Schülern die Kompetenz mitzugeben, sich zu jedem beliebigen Thema informieren zu können, dabei technische Hilfsmittel zum Sichten großer Datenmengen zu nutzen, und erfolgreich Fakten von Meinungen und seriöse Berichterstattung von Fake News zu trennen. Ein derartiger Bildungsprozess muss sicherlich mit digitalen Hilfsmitteln arbeiten. Aber er fokussiert sich auf die Dinge, die Menschen wirklich gut machen: kreatives und kritisches Denken. Und er überlässt den Maschinen die Dinge, die sie besser können: Routinetätigkeiten und die Verarbeitung großer Datenmengen.

Und doch, oder vielleicht gerade deshalb, trägt dieser Text die Überschrift "Von Maschinen fürs Leben lernen". Im Folgenden werden beispielhaft drei Lebenslektionen besprochen, die der Autor aus seinem Studium der Informatik sowie aus seiner Tätigkeit in der IT-Branche gezogen hat, und die unserer Meinung nach in den Lehrplänen aktuell zu wenig Beachtung finden. Solange dies so bleibt, könnte auch ein Computermuseum wie das ZCOM entsprechende Impulse setzen.

## Lektion 1: Game of Life

Vielleicht nicht eines der wichtigsten, aber sicherlich eines der bekanntesten Untersuchungsobjekte der Informatik ist "Conway's Game of Life" (GoL). Hierbei handelt es sich um einen zellulären Automaten, also eine Anordnung von Zellen, wobei jede Zelle einen bestimmten Zustand hat und diesen Zustand in festen diskreten Zeitschritten nach bestimmten Regeln wechseln kann. Man kann zelluläre Automaten in beliebig vielen Raumdimensionen und mit allen denkbaren Zellformen konstruieren.

Im konkreten Fall von GoL haben wir ein zweidimensionales Raster aus quadratischen Zellen. Eine Zelle kann zwei mögliche Zustände einnehmen, die für gewöhnlich als "tot" oder "lebendig" bezeichnet werden. Für den Wechsel zwischen diesen beiden Zuständen ist die direkte Nachbarschaft der Zelle relevant, sprich: die Zustände der acht im Quadratraster nächstgelegenen Zellen (oben, unten, links, rechts, plus vier Nachbarn in diagonaler Richtung). Eine tote Zelle wird lebendig, wenn sie exakt drei lebendige Nachbarn hat. Eine lebendige Zelle mit keinem oder nur einem lebendigem Nachbarn stirbt an Vereinsamung, und eine lebendige Zelle mit vier or mehr lebendigen Nachbarn stirbt an Überbevölkerung.

Nun wird der Platz in diesem Aufsatz sicher nicht ausreichen, um eine komplette Diskussion des Verhaltens von GoL zu führen. Und selbst dann hätten wir in einem gedruckten Buch keine gute Möglichkeit, das zeitabhängige Verhalten eines GoL-Spiels abzubilden. Hierfür eignen sich besser Videos oder Live-Simulationen. Sofern der Leser noch nicht mit GoL vertraut ist, ist daher dringend empfohlen, mit einem entsprechenden Simulationsprogramm herumzuexperimentieren. Zum Zeitpunkt der Publikation dieses Textes ist zum Beispiel unter <https://playgameoflife.com> ein derartiges Programm zu finden, welches ohne Installation im Browser läuft und ein umfangreiches Lexikon mit interessanten Startmustern enthält. Der Wikipedia-Artikel zu GoL ist ebenfalls ein guter Startpunkt für eine weitere Auseinandersetzung mit diesem Thema.

GoL wurde im Jahre 1970 von einer Forschergruppe um den britischen Mathematiker John Horton Conway vorgeschlagen. Sie fanden erste interessante Strukturen: Stillleben, die sich nie verändern, und Oszillatoren, die sich verändern, aber nach einer bestimmten Anzahl von Zeitschritten wieder in den Ursprungszustand zurückkehren. Außerdem fanden sie den Gleiter, ein Muster aus 5 lebendigen Zellen, das ähnlich wie ein Oszillator nach vier Zeitschritten wieder in seine ursprüngliche Form zurückkehrt, sich dabei aber diagonal um ein Feld weiterbewegt. Derartige Muster werden im Allgemeinen als Raumschiffe bezeichnet, und nach der initialen Publikation durch die Conway-Gruppe fanden Interessierte schnell weitere Raumschiffe mit unterschiedlichen Bewegungsmustern.

In der initialen Publikation bot Conway ein Preisgeld von 50 US-Dollar für ein Muster, das unbegrenzt wächst. Noch im selben Jahr wurde ein derartiges Muster gefunden: eine sogenannte "Gleiterkanone", die in regelmäßigen Zeitabständen einen Gleiter produziert, der sich dann von der Kanone wegbewegt. Hierdurch kommt ein endloser Strom von Gleitern zustande. Auch für andere Raumschiffe konnten Kanonen konstruiert werden.

Mit der Zeit wurden immer komplexere Strukturen in GoL gebaut. So wie Kanonen Ströme von Raumschiffen erzeugen, können bestimmte Kanonen auch durch Ströme von Raumschiffen an- oder ausgeschaltet werden. Durch strategisches Ausrichten der Raumschiffströme können Kanonen sich gegenseitig kontrollieren und so Logikgatter bilden, aus denen dann ganze Computer gebaut werden können. Im Jahr 2012 gelang die erste Simulation von GoL innerhalb eines GoL-Spielfeldes. (TODO: Link zum Video) Dies demonstriert eindrucksvoll, dass GoL trotz des minimalistischen Regelsatzes turingvollständig ist, sprich: Alle mit einem Computer lösbaren Probleme können theoretisch auch in GoL berechnet werden.

Wenn wir an "Komplexität" denken, denken wir an Systeme mit besonders vielen Regeln, zum Beispiel die Steuergesetzgebung. Viel häufiger jedoch resultiert komplexes Verhalten aus einem System mit einer vergleichsweise kleinen Menge von Regeln, die aber von sehr vielen Akteuren gleichzeitig ausgeführt werden. GoL ist eines der greifbarsten und verständlichsten Beispiele für derartige "emergente Komplexität". Wenn hunderte Zellen an einer Gleiterkanone teilnehmen, hatte die einzelne Zelle keine konkrete Absicht, eine Gleiterkanone zu bilden. Wie eine biologische Zelle kennt sie nur ihre direkte Nachbarschaft und verhält sich dementsprechend, ohne ihren Anteil am Gesamtorganismus zu verstehen.

Emergente Komplexität gibt es nicht nur in der Technik oder der Biologie. Gesellschaft, Wirtschaft und Politik sind selbst Systeme mit vielen Akteuren, die individuell nach relativ überschaubaren Regeln handeln und deshalb zu emergenter Komplexität neigen. Wer das nicht versteht, ist dazu verurteilt, hypothetischen Entitäten wie "dem Markt" oder "der Politik" Intentionen zu unterstellen, die auf dieser Ebene einfach nicht existieren. Wer hingegen emergente Komplexität auf einer intuitiven Ebene nachvollziehen kann, zum Beispiel durch das Studium von GoL, versteht vielleicht besser, welche politischen Maßnahmen tatsächlich effektiv sind, und in welchen Situationen Simulationen wie in der Epidemiologie oder Computational Sociology zum Verständnis emergent komplexer Systeme beitragen.
